% marko.m predicts the present state of a calcium sensor depending upon its 
% previous state. It generates a URN 'u' and returns index 'i' for which u  
% is greater than p(i), where p is the transition probability matrix with
% the sum of each elements of the column equal to '1'
% This method of markov process simulation can be read from the book:
% 'Computational Cell Biology' by Christopher P. Fall et al (2002) 
% page number: 291-292.
% The value of i=1,2,3,...,7. If i=1 it denotes sensor has no calcium 
% bound and if i=7 then sensor has 5 calcium bound and is in isomerized
% state. See equation (6) of Tewari, S. and Majumdar, K. (2012). "A 
% Mathematical Model for Astrocytes Mediated LTP at Single Hippocampal 
% Synapses," Journal of Computational Neuroscience.

function [state] = marko(p)
u=rand;% URN
i=1;% Initial value of i
s=p(1);% Probability to stay in the present state

while ((u>s) && (i<length(p)))
  i=i+1;% 
  s=s+p(i);%
end

state=i;% i denotes the present state. 

